prometheus

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2021 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	ProviderType = "Prometheus"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Option added in v0.9.8

type Option func(*Provider)

func WithBasicAuth added in v0.9.8

func WithBasicAuth(username, password string) Option

func WithLogger added in v0.9.8

func WithLogger(logger *zap.Logger) Option

func WithTimeout added in v0.9.8

func WithTimeout(timeout time.Duration) Option

type Provider

type Provider struct {
	// contains filtered or unexported fields
}

Provider is a client for prometheus.

func NewProvider

func NewProvider(address string, opts ...Option) (*Provider, error)

func (*Provider) Evaluate added in v0.9.8

func (p *Provider) Evaluate(ctx context.Context, query string, queryRange metrics.QueryRange, evaluator metrics.Evaluator) (bool, string, error)

Evaluate queries the range query endpoint and checks if values in all data points are within the expected range. For the range query endpoint, see: https://prometheus.io/docs/prometheus/latest/querying/api/#range-queries

func (*Provider) Type

func (p *Provider) Type() string

Jump to