Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Getter ¶
type Getter interface {
// GetLatest returns the latest event that meets the given conditions.
GetLatest(ctx context.Context, name string, labels map[string]string) (*model.Event, bool)
}
Getter helps get an event. All objects returned here must be treated as read-only.
Click to show internal directories.
Click to hide internal directories.