package
Version:
v0.1.3
Opens a new window with list of versions in this module.
Published: Jul 1, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Register(r registerer)
Register registers this executor factory into a given registerer.
Execute starts waiting for the specified duration.
TODO: Persist and load the start time to deal with restart case.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.