Documentation
¶
Overview ¶
Package trigger provides a piped component that detects a list of application should be synced (by new commit, sync command or configuration drift) and then sends request to the control-plane to create a new Deployment.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Determiner ¶ added in v0.10.3
type Determiner interface {
ShouldTrigger(ctx context.Context, app *model.Application, appCfg *config.GenericApplicationSpec) (bool, error)
}
func NewOnCommitDeterminer ¶ added in v0.22.0
func NewOnCommitDeterminer(repo git.Repo, targetCommit string, cg LastTriggeredCommitGetter, logger *zap.Logger) Determiner
type LastTriggeredCommitGetter ¶ added in v0.10.3
type OnChainDeterminer ¶ added in v0.22.0
type OnChainDeterminer struct {
}
func NewOnChainDeterminer ¶ added in v0.22.0
func NewOnChainDeterminer() *OnChainDeterminer
func (*OnChainDeterminer) ShouldTrigger ¶ added in v0.22.0
func (d *OnChainDeterminer) ShouldTrigger(_ context.Context, _ *model.Application, appCfg *config.GenericApplicationSpec) (bool, error)
type OnCommandDeterminer ¶ added in v0.22.0
type OnCommandDeterminer struct {
}
func NewOnCommandDeterminer ¶ added in v0.22.0
func NewOnCommandDeterminer() *OnCommandDeterminer
func (*OnCommandDeterminer) ShouldTrigger ¶ added in v0.22.0
func (d *OnCommandDeterminer) ShouldTrigger(_ context.Context, _ *model.Application, appCfg *config.GenericApplicationSpec) (bool, error)
ShouldTrigger decides whether a given application should be triggered or not.
type OnCommitDeterminer ¶ added in v0.22.0
type OnCommitDeterminer struct {
// contains filtered or unexported fields
}
func (*OnCommitDeterminer) ShouldTrigger ¶ added in v0.22.0
func (d *OnCommitDeterminer) ShouldTrigger(ctx context.Context, app *model.Application, appCfg *config.GenericApplicationSpec) (bool, error)
ShouldTrigger decides whether a given application should be triggered or not.
type OnOutOfSyncDeterminer ¶ added in v0.22.0
type OnOutOfSyncDeterminer struct {
// contains filtered or unexported fields
}
func NewOnOutOfSyncDeterminer ¶ added in v0.22.0
func NewOnOutOfSyncDeterminer(client apiClient) *OnOutOfSyncDeterminer
func (*OnOutOfSyncDeterminer) ShouldTrigger ¶ added in v0.22.0
func (d *OnOutOfSyncDeterminer) ShouldTrigger(ctx context.Context, app *model.Application, appCfg *config.GenericApplicationSpec) (bool, error)
ShouldTrigger decides whether a given application should be triggered or not.
type Trigger ¶
type Trigger struct {
// contains filtered or unexported fields
}
func NewTrigger ¶
func (*Trigger) GetLastTriggeredCommitGetter ¶ added in v0.10.3
func (t *Trigger) GetLastTriggeredCommitGetter() LastTriggeredCommitGetter
Click to show internal directories.
Click to hide internal directories.