Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetValue ¶
GetValue gives back the value placed at a given path. The type of returned value can be string, int64, uint64, float64 and bool.
The path requires to start with "$" which represents the root element. Available operators are: $ : the root object/element . : child operator .. : recursive descent [num] : object/element of array by number
e.g. "$.foo.bar[0].baz"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.