Documentation
¶
Index ¶
Constants ¶
const (
ProviderType = "Prometheus"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶ added in v0.9.8
type Option func(*Provider)
func WithBasicAuth ¶ added in v0.9.8
func WithLogger ¶ added in v0.9.8
func WithTimeout ¶ added in v0.9.8
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider is a client for prometheus.
func (*Provider) Evaluate ¶ added in v0.9.8
func (p *Provider) Evaluate(ctx context.Context, query string, queryRange metrics.QueryRange, evaluator metrics.Evaluator) (bool, string, error)
Evaluate queries the range query endpoint and checks if values in all data points are within the expected range. For the range query endpoint, see: https://prometheus.io/docs/prometheus/latest/querying/api/#range-queries
Click to show internal directories.
Click to hide internal directories.