Documentation
¶
Index ¶
- Constants
- Variables
- func ToApplicationKind(k Kind) (model.ApplicationKind, bool)
- type AnalysisDynamic
- type AnalysisDynamicHTTP
- type AnalysisDynamicLog
- type AnalysisDynamicMetrics
- type AnalysisExpected
- type AnalysisHTTP
- type AnalysisHeader
- type AnalysisLog
- type AnalysisMetrics
- type AnalysisProviderDatadogConfig
- type AnalysisProviderPrometheusConfig
- type AnalysisProviderStackdriverConfig
- type AnalysisStageOptions
- type AnalysisTemplateRef
- type AnalysisTemplateSpec
- type CloudProviderCloudRunConfig
- type CloudProviderKubernetesConfig
- type CloudProviderLambdaConfig
- type CloudProviderTerraformConfig
- type CloudRunDeploymentInput
- type CloudRunDeploymentSpec
- type CloudRunPromoteStageOptions
- type CloudRunSyncStageOptions
- type Config
- type ControlPlaneCache
- type ControlPlaneDataStore
- type ControlPlaneFileStore
- type ControlPlaneProject
- type ControlPlaneSpec
- type DataStoreDynamoDBConfig
- type DataStoreFireStoreConfig
- type DataStoreMongoDBConfig
- type DeploymentCommitMatcher
- type DeploymentPipeline
- type Duration
- type FileStoreGCSConfig
- type FileStoreMinioConfig
- type FileStoreS3Config
- type HelmChartRepository
- type InputHelmChart
- type InputHelmOptions
- type IstioTrafficRouting
- type K8sBaselineCleanStageOptions
- type K8sBaselineRolloutStageOptions
- type K8sCanaryCleanStageOptions
- type K8sCanaryRolloutStageOptions
- type K8sPrimaryRolloutStageOptions
- type K8sResourceReference
- type K8sSyncStageOptions
- type K8sTrafficRoutingStageOptions
- type Kind
- type KubernetesAppStateInformer
- type KubernetesDeploymentInput
- type KubernetesDeploymentSpec
- type KubernetesResourceMatcher
- type KubernetesTrafficRouting
- type KubernetesTrafficRoutingMethod
- type LambdaCanaryRolloutStageOptions
- type LambdaDeploymentInput
- type LambdaDeploymentSpec
- type LambdaPromoteStageOptions
- type LambdaSyncStageOptions
- type NotificationReceiver
- type NotificationReceiverSlack
- type NotificationReceiverWebhook
- type NotificationRoute
- type Notifications
- type PipedAnalysisProvider
- type PipedCloudProvider
- type PipedGit
- type PipedRepository
- type PipedSpec
- func (s *PipedSpec) EnableDefaultKubernetesCloudProvider()
- func (s *PipedSpec) FindCloudProvider(name string, t model.CloudProviderType) (PipedCloudProvider, bool)
- func (s *PipedSpec) GetAnalysisProvider(name string) (PipedAnalysisProvider, bool)
- func (s *PipedSpec) GetRepository(id string) (PipedRepository, bool)
- func (s *PipedSpec) GetRepositoryMap() map[string]PipedRepository
- func (s *PipedSpec) HasCloudProvider(name string, t model.CloudProviderType) bool
- func (s *PipedSpec) Validate() error
- type PipelineStage
- type Pipelineable
- type ProjectStaticUser
- type Replicas
- type SharedSSOConfig
- type TemplatableAnalysisHTTP
- type TemplatableAnalysisLog
- type TemplatableAnalysisMetrics
- type TerraformApplyStageOptions
- type TerraformDeploymentInput
- type TerraformDeploymentSpec
- type TerraformPlanStageOptions
- type TerraformSyncStageOptions
- type WaitApprovalStageOptions
- type WaitStageOptions
Constants ¶
const (
)
Variables ¶
var DefaultKubernetesCloudProvider = PipedCloudProvider{ Name: "kubernetes-default", Type: model.CloudProviderKubernetes, KubernetesConfig: &CloudProviderKubernetesConfig{}, }
Functions ¶
func ToApplicationKind ¶
func ToApplicationKind(k Kind) (model.ApplicationKind, bool)
ToApplicationKind converts configuration kind to application kind.
Types ¶
type AnalysisDynamic ¶
type AnalysisDynamic struct {
Metrics []AnalysisDynamicMetrics `json:"metrics"`
Logs []AnalysisDynamicLog `json:"logs"`
Https []AnalysisDynamicHTTP `json:"https"`
}
AnalysisDynamic contains settings for analysis by comparing with dynamic data.
type AnalysisDynamicHTTP ¶
type AnalysisDynamicLog ¶
type AnalysisDynamicMetrics ¶
type AnalysisExpected ¶
AnalysisExpected defines the range used for metrics analysis.
type AnalysisHTTP ¶
type AnalysisHTTP struct {
URL string `json:"url"`
Method string `json:"method"`
// Custom headers to set in the request. HTTP allows repeated headers.
Headers []AnalysisHeader `json:"headers"`
ExpectedCode int `json:"expectedCode"`
ExpectedResponse string `json:"expectedResponse"`
Interval Duration `json:"interval"`
// Maximum number of failed checks before the response is considered as failure.
FailureLimit int `json:"failureLimit"`
Timeout Duration `json:"timeout"`
}
AnalysisHTTP contains common configurable values for deployment analysis with http.
type AnalysisHeader ¶
type AnalysisLog ¶
type AnalysisLog struct {
Query string `json:"query"`
Interval Duration `json:"interval"`
// Maximum number of failed checks before the query result is considered as failure.
FailureLimit int `json:"failureLimit"`
// How long after which the query times out.
Timeout Duration `json:"timeout"`
Provider string `json:"provider"`
}
AnalysisLog contains common configurable values for deployment analysis with log.
type AnalysisMetrics ¶
type AnalysisMetrics struct {
Query string `json:"query"`
Expected AnalysisExpected `json:"expected"`
Interval Duration `json:"interval"`
// Maximum number of failed checks before the query result is considered as failure.
// For instance, If 1 is set, the analysis will be considered a failure after 2 failures.
FailureLimit int `json:"failureLimit"`
// How long after which the query times out.
Timeout Duration `json:"timeout"`
Provider string `json:"provider"`
}
AnalysisMetrics contains common configurable values for deployment analysis with metrics.
type AnalysisProviderStackdriverConfig ¶
type AnalysisProviderStackdriverConfig struct {
// The path to the service account file.
ServiceAccountFile string `json:"serviceAccountFile"`
}
type AnalysisStageOptions ¶
type AnalysisStageOptions struct {
// How long the analysis process should be executed.
Duration Duration `json:"duration"`
// TODO: Consider about how to handle a pod restart
// possible count of pod restarting
RestartThreshold int `json:"restartThreshold"`
Metrics []TemplatableAnalysisMetrics `json:"metrics"`
Logs []TemplatableAnalysisLog `json:"logs"`
Https []TemplatableAnalysisHTTP `json:"https"`
Dynamic AnalysisDynamic `json:"dynamic"`
}
AnalysisStageOptions contains all configurable values for a K8S_ANALYSIS stage.
type AnalysisTemplateRef ¶
type AnalysisTemplateSpec ¶
type AnalysisTemplateSpec struct {
Metrics map[string]AnalysisMetrics `json:"metrics"`
Logs map[string]AnalysisLog `json:"logs"`
HTTPs map[string]AnalysisHTTP `json:"https"`
}
func LoadAnalysisTemplate ¶
func LoadAnalysisTemplate(repoRoot string) (*AnalysisTemplateSpec, bool, error)
LoadAnalysisTemplate finds the config file for the analysis template in the .pipe directory first up. And returns parsed config, False is returned as the second returned value if not found.
func (*AnalysisTemplateSpec) Validate ¶
func (s *AnalysisTemplateSpec) Validate() error
type CloudProviderKubernetesConfig ¶
type CloudProviderKubernetesConfig struct {
AppStateInformer KubernetesAppStateInformer `json:"appStateInformer"`
MasterURL string `json:"masterURL"`
KubeConfigPath string `json:"kubeConfigPath"`
}
type CloudProviderLambdaConfig ¶
type CloudProviderLambdaConfig struct {
Region string `json:"region"`
}
type CloudProviderTerraformConfig ¶
type CloudProviderTerraformConfig struct {
// The name of directory where to put the configured credentials files.
// Default is ".terraform-credentials"
CredentialsDirName string `json:"credentialsDirName"`
// List of credentials files that will be copied to the CredentialsDir before running terraform commands.
CredentialsFiles []string `json:"credentialsFiles"`
// List of variables that will be set directly on terraform commands with "-var" flag.
// The variable must be formatted by "key=value" as below:
// "image_id=ami-abc123"
// 'image_id_list=["ami-abc123","ami-def456"]'
// 'image_id_map={"us-east-1":"ami-abc123","us-east-2":"ami-def456"}'
Vars []string `json:"vars"`
}
type CloudRunDeploymentInput ¶ added in v0.3.0
type CloudRunDeploymentInput struct {
// The name of service manifest file placing in application configuration directory.
// Default is service.yaml
ServiceManifestFile string `json:"serviceManifestFile"`
// Automatically reverts all changes from all stages when one of them failed.
// Default is true.
AutoRollback bool `json:"autoRollback"`
}
type CloudRunDeploymentSpec ¶ added in v0.3.0
type CloudRunDeploymentSpec struct {
// Input for CloudRun deployment such as docker image...
Input CloudRunDeploymentInput `json:"input"`
// Configuration for quick sync.
QuickSync CloudRunSyncStageOptions `json:"quickSync"`
// Pipline for deploying progressively.
Pipeline *DeploymentPipeline `json:"pipeline"`
}
CloudRunDeploymentSpec represents a deployment configuration for CloudRun application.
func (*CloudRunDeploymentSpec) GetStage ¶ added in v0.3.0
func (s *CloudRunDeploymentSpec) GetStage(index int32) (PipelineStage, bool)
func (*CloudRunDeploymentSpec) Validate ¶ added in v0.3.0
func (s *CloudRunDeploymentSpec) Validate() error
Validate returns an error if any wrong configuration value was found.
type CloudRunPromoteStageOptions ¶ added in v0.4.0
type CloudRunPromoteStageOptions struct {
Percent int `json:"percent"`
}
CloudRunPromoteStageOptions contains all configurable values for a CLOUDRUN_PROMOTE stage.
type CloudRunSyncStageOptions ¶ added in v0.3.0
type CloudRunSyncStageOptions struct {
}
CloudRunSyncStageOptions contains all configurable values for a CLOUDRUN_SYNC stage.
type Config ¶
type Config struct {
Kind Kind
APIVersion string
// Deployment specs.
KubernetesDeploymentSpec *KubernetesDeploymentSpec
TerraformDeploymentSpec *TerraformDeploymentSpec
CloudRunDeploymentSpec *CloudRunDeploymentSpec
LambdaDeploymentSpec *LambdaDeploymentSpec
PipedSpec *PipedSpec
ControlPlaneSpec *ControlPlaneSpec
AnalysisTemplateSpec *AnalysisTemplateSpec
// contains filtered or unexported fields
}
Config represents configuration data load from file. The spec is depend on the kind of configuration.
func DecodeYAML ¶
DecodeYAML unmarshals config YAML data to config struct. It also validates the configuration after decoding.
func LoadFromYAML ¶
LoadFromYAML reads and decodes a yaml file to construct the Config.
func (*Config) GetPipelineable ¶
func (c *Config) GetPipelineable() (Pipelineable, bool)
func (*Config) UnmarshalJSON ¶
UnmarshalJSON customizes the way to unmarshal json data into Config struct. Firstly, this unmarshal to a generic config and then unmarshal the spec which depend on the kind of configuration.
type ControlPlaneCache ¶
type ControlPlaneCache struct {
TTL Duration `json:"ttl"`
}
func (ControlPlaneCache) TTLDuration ¶ added in v0.6.0
func (c ControlPlaneCache) TTLDuration() time.Duration
type ControlPlaneDataStore ¶
type ControlPlaneDataStore struct {
// The datastore type.
Type model.DataStoreType
// The configuration in the case of Cloud Firestore.
FirestoreConfig *DataStoreFireStoreConfig
// The configuration in the case of Amazon DynamoDB.
DynamoDBConfig *DataStoreDynamoDBConfig
// The configuration in the case of general MongoDB.
MongoDBConfig *DataStoreMongoDBConfig
}
func (*ControlPlaneDataStore) UnmarshalJSON ¶
func (d *ControlPlaneDataStore) UnmarshalJSON(data []byte) error
type ControlPlaneFileStore ¶
type ControlPlaneFileStore struct {
// The filestore type.
Type model.FileStoreType
// The configuration in the case of Google Cloud Storage.
GCSConfig *FileStoreGCSConfig `json:"gcs"`
// The configuration in the case of Amazon S3.
S3Config *FileStoreS3Config `json:"s3"`
// The configuration in the case of Minio.
MinioConfig *FileStoreMinioConfig `json:"minio"`
}
func (*ControlPlaneFileStore) UnmarshalJSON ¶
func (f *ControlPlaneFileStore) UnmarshalJSON(data []byte) error
type ControlPlaneProject ¶
type ControlPlaneProject struct {
Id string `json:"id"`
Desc string `json:"desc"`
StaticAdmin ProjectStaticUser `json:"staticAdmin"`
}
type ControlPlaneSpec ¶
type ControlPlaneSpec struct {
// The address to the control plane.
Address string `json:"address"`
// A random key to generate oauth state paramater.
StateKey string `json:"stateKey"`
// List of debugging/quickstart projects defined in Control Plane configuration.
// Please note that do not use this to configure the projects running the production.
Projects []ControlPlaneProject `json:"projects"`
SharedSSOConfigs []SharedSSOConfig `json:"sharedSSOConfigs"`
// The configuration of datastore for control plane.
Datastore ControlPlaneDataStore `json:"datastore"`
// The configuration of filestore for control plane.
Filestore ControlPlaneFileStore `json:"filestore"`
// The configuration of cache for control plane.
Cache ControlPlaneCache `json:"cache"`
}
ControlPlaneSpec defines all configuration for all control-plane components.
func (*ControlPlaneSpec) FindProject ¶ added in v0.6.0
func (s *ControlPlaneSpec) FindProject(id string) (ControlPlaneProject, bool)
FindProject finds and returns a specific project in the configured list.
func (*ControlPlaneSpec) ProjectMap ¶ added in v0.6.0
func (s *ControlPlaneSpec) ProjectMap() map[string]ControlPlaneProject
func (*ControlPlaneSpec) SharedSSOConfigMap ¶ added in v0.6.0
func (s *ControlPlaneSpec) SharedSSOConfigMap() map[string]*model.ProjectSSOConfig
func (*ControlPlaneSpec) Validate ¶
func (s *ControlPlaneSpec) Validate() error
type DataStoreDynamoDBConfig ¶
type DataStoreDynamoDBConfig struct {
}
type DataStoreFireStoreConfig ¶
type DataStoreFireStoreConfig struct {
// The identifier that logically separates the root path of the datastore.
Namespace string `json:"namespace"`
// The identifier that logically separates directly under the namespace of the datastore.
Environment string `json:"environment"`
// The identifier of the GCP project which host the firestore.
Project string `json:"project"`
// The path to the credentials file for accessing firestore.
CredentialsFile string `json:"credentialsFile"`
}
type DataStoreMongoDBConfig ¶
type DataStoreMongoDBConfig struct {
// The url of MongoDB. All of credentials can be specified via this field.
URL string `json:"url"`
// The name of the database.
Database string `json:"database"`
// The path to the username file.
// For those who don't want to include the username in the URL.
UsernameFile string `json:"usernameFile"`
// The path to the password file.
// For those who don't want to include the password in the URL.
PasswordFile string `json:"passwordFile"`
}
type DeploymentCommitMatcher ¶ added in v0.1.6
type DeploymentCommitMatcher struct {
// It makes sure to perform syncing if the commit message matches this regular expression.
QuickSync string `json:"quickSync"`
// It makes sure to perform pipeline if the commit message matches this regular expression.
Pipeline string `json:"pipeline"`
}
DeploymentCommitMatcher provides a way to decide how to deploy.
type DeploymentPipeline ¶
type DeploymentPipeline struct {
Stages []PipelineStage `json:"stages"`
}
DeploymentPipeline represents the way to deploy the application. The pipeline is triggered by changes in any of the following objects: - Target PodSpec (Target can be Deployment, DaemonSet, StatefullSet) - ConfigMaps, Secrets that are mounted as volumes or envs in the deployment.
type FileStoreGCSConfig ¶
type FileStoreMinioConfig ¶
type FileStoreMinioConfig struct {
Endpoint string `json:"endpoint"`
// The bucket name to store.
Bucket string `json:"bucket"`
// The path to the access key file.
AccessKeyFile string `json:"accessKeyFile"`
// The path to the secret key file.
SecretKeyFile string `json:"secretKeyFile"`
// The given bucket is made automatically if not exists.
AutoCreateBucket bool `json:"autoCreateBucket"`
}
type FileStoreS3Config ¶
type FileStoreS3Config struct {
}
type HelmChartRepository ¶ added in v0.1.2
type InputHelmChart ¶
type InputHelmChart struct {
// Git remote address where the chart is placing.
// Empty means the same repository.
GitRemote string `json:"gitRemote"`
// The commit SHA or tag for remote git.
Ref string `json:"ref"`
// Relative path from the repository root directory to the chart directory.
Path string `json:"path"`
// The name of an added Helm Chart Repository.
Repository string `json:"repository"`
Name string `json:"name"`
Version string `json:"version"`
}
type InputHelmOptions ¶ added in v0.1.2
type InputHelmOptions struct {
// The release name of helm deployment.
// By default the release name is equal to the application name.
ReleaseName string `json:"releaseName"`
// List of value files should be loaded.
ValueFiles []string `json:"valueFiles"`
// List of file path for values.
SetFiles map[string]string
}
type IstioTrafficRouting ¶ added in v0.1.5
type IstioTrafficRouting struct {
// List of routes in the VirtualService that can be changed to update traffic routing.
// Empty means all routes should be updated.
EditableRoutes []string `json:"editableRoutes"`
// TODO: Add a validate to ensure this was configured or using the default value by service name.
// The service host.
Host string `json:"host"`
// The reference to VirtualService manifest.
// Empty means the first VirtualService resource will be used.
VirtualService K8sResourceReference `json:"virtualService"`
}
type K8sBaselineCleanStageOptions ¶
type K8sBaselineCleanStageOptions struct {
}
K8sBaselineCleanStageOptions contains all configurable values for a K8S_BASELINE_CLEAN stage.
type K8sBaselineRolloutStageOptions ¶
type K8sBaselineRolloutStageOptions struct {
// How many pods for BASELINE workloads.
// An integer value can be specified to indicate an absolute value of pod number.
// Or a string suffixed by "%" to indicate an percentage value compared to the pod number of PRIMARY.
// Default is 1 pod.
Replicas Replicas `json:"replicas"`
// Suffix that should be used when naming the BASELINE variant's resources.
// Default is "baseline".
Suffix string `json:"suffix"`
// Whether the BASELINE service should be created.
CreateService bool `json:"createService"`
}
K8sBaselineRolloutStageOptions contains all configurable values for a K8S_BASELINE_ROLLOUT stage.
type K8sCanaryCleanStageOptions ¶
type K8sCanaryCleanStageOptions struct {
}
K8sCanaryCleanStageOptions contains all configurable values for a K8S_CANARY_CLEAN stage.
type K8sCanaryRolloutStageOptions ¶
type K8sCanaryRolloutStageOptions struct {
// How many pods for CANARY workloads.
// An integer value can be specified to indicate an absolute value of pod number.
// Or a string suffixed by "%" to indicate an percentage value compared to the pod number of PRIMARY.
// Default is 1 pod.
Replicas Replicas `json:"replicas"`
// Suffix that should be used when naming the CANARY variant's resources.
// Default is "canary".
Suffix string `json:"suffix"`
// Whether the CANARY service should be created.
CreateService bool `json:"createService"`
}
K8sCanaryRolloutStageOptions contains all configurable values for a K8S_CANARY_ROLLOUT stage.
type K8sPrimaryRolloutStageOptions ¶ added in v0.1.5
type K8sPrimaryRolloutStageOptions struct {
// Suffix that should be used when naming the PRIMARY variant's resources.
// Default is "primary".
Suffix string `json:"suffix"`
// Whether the PRIMARY service should be created.
CreateService bool `json:"createService"`
// Whether the PRIMARY variant label should be added to manifests if they were missing.
AddVariantLabelToSelector bool `json:"addVariantLabelToSelector"`
// Whether the resources that are no longer defined in Git should be removed or not.
Prune bool `json:"prune"`
}
K8sPrimaryRolloutStageOptions contains all configurable values for a K8S_PRIMARY_ROLLOUT stage.
type K8sResourceReference ¶ added in v0.1.5
type K8sSyncStageOptions ¶ added in v0.1.6
type K8sSyncStageOptions struct {
// Whether the PRIMARY variant label should be added to manifests if they were missing.
AddVariantLabelToSelector bool `json:"addVariantLabelToSelector"`
// Whether the resources that are no longer defined in Git should be removed or not.
Prune bool `json:"prune"`
}
K8sSyncStageOptions contains all configurable values for a K8S_SYNC stage.
type K8sTrafficRoutingStageOptions ¶ added in v0.1.5
type K8sTrafficRoutingStageOptions struct {
// Which variant should receive all traffic.
// "primary" or "canary" or "baseline" can be populated.
All string `json:"all"`
// The percentage of traffic should be routed to PRIMARY variant.
Primary int `json:"primary"`
// The percentage of traffic should be routed to CANARY variant.
Canary int `json:"canary"`
// The percentage of traffic should be routed to BASELINE variant.
Baseline int `json:"baseline"`
}
K8sTrafficRoutingStageOptions contains all configurable values for a K8S_TRAFFIC_ROUTING stage.
func (K8sTrafficRoutingStageOptions) Percentages ¶ added in v0.1.5
func (opts K8sTrafficRoutingStageOptions) Percentages() (primary, canary, baseline int)
type Kind ¶
type Kind string
Kind represents the kind of configuration the data contains.
const ( // KindKubernetesApp represents deployment configuration for a Kubernetes application. // This application can be a group of plain-YAML Kubernetes manifests, // or kustomization manifests or helm manifests. KindKubernetesApp Kind = "KubernetesApp" // KindTerraformApp represents deployment configuration for a Terraform application. // This application contains a single workspace of a terraform root module. KindTerraformApp Kind = "TerraformApp" // KindCrossplaneApp represents deployment configuration for a Crossplane application. KindCrossplaneApp Kind = "CrossplaneApp" // KindLambdaApp represents deployment configuration for an AWS Lambda application. KindLambdaApp Kind = "LambdaApp" // KindCloudRunApp represents deployment configuration for a CloudRun application. KindCloudRunApp Kind = "CloudRunApp" )
const ( // KindPiped represents configuration for piped. // This configuration will be loaded while the piped is starting up. KindPiped Kind = "Piped" // KindControlPlane represents configuration for control plane's services. KindControlPlane Kind = "ControlPlane" // KindAnalysisTemplate represents shared analysis template for a repository. // This configuration file should be placed in .pipe directory // at the root of the repository. KindAnalysisTemplate Kind = "AnalysisTemplate" )
type KubernetesAppStateInformer ¶ added in v0.1.1
type KubernetesAppStateInformer struct {
// Only watches the specified namespace.
// Empty means watching all namespaces.
Namespace string `json:"namespace"`
// List of resources that should be added to the watching targets.
IncludeResources []KubernetesResourceMatcher `json:"includeResources"`
// List of resources that should be ignored from the watching targets.
ExcludeResources []KubernetesResourceMatcher `json:"excludeResources"`
}
type KubernetesDeploymentInput ¶
type KubernetesDeploymentInput struct {
// List of manifest files in the application configuration directory used to deploy.
// Empty means all manifest files in the directory will be used.
Manifests []string `json:"manifests"`
// Version of kubectl will be used.
KubectlVersion string `json:"kubectlVersion"`
// Version of kustomize will be used.
KustomizeVersion string `json:"kustomizeVersion"`
// Version of helm will be used.
HelmVersion string `json:"helmVersion"`
// Where to fetch helm chart.
HelmChart *InputHelmChart `json:"helmChart"`
// COnfigurable parameters for helm commands.
HelmOptions *InputHelmOptions `json:"helmOptions"`
// The namespace where manifests will be applied.
Namespace string `json:"namespace"`
// Automatically reverts all deployment changes on failure.
// Default is true.
AutoRollback bool `json:"autoRollback"`
// List of directories where their changes will trigger the deployment.
Dependencies []string `json:"dependencies,omitempty"`
}
KubernetesDeploymentInput represents needed input for triggering a Kubernetes deployment.
type KubernetesDeploymentSpec ¶
type KubernetesDeploymentSpec struct {
// Input for Kubernetes deployment such as kubectl version, helm version, manifests filter...
Input KubernetesDeploymentInput `json:"input"`
// Forcibly use QuickSync or Pipeline when commit message matched the specified format.
CommitMatcher DeploymentCommitMatcher `json:"commitMatcher"`
// Configuration for quick sync.
QuickSync K8sSyncStageOptions `json:"quickSync"`
// Pipeline for deploying progressively.
Pipeline *DeploymentPipeline `json:"pipeline"`
// Which resource should be considered as the Service of application.
// Empty means the first Service resource will be used.
Service K8sResourceReference `json:"service"`
// Which resources should be considered as the Workload of application.
// Empty means all Deployments.
// e.g.
// - kind: Deployment
// name: deployment-name
// - kind: ReplicationController
// name: replication-controller-name
Workloads []K8sResourceReference `json:"workloads"`
// Which method should be used for traffic routing.
TrafficRouting *KubernetesTrafficRouting `json:"trafficRouting"`
}
KubernetesDeploymentSpec represents a deployment configuration for Kubernetes application.
func (*KubernetesDeploymentSpec) GetStage ¶
func (s *KubernetesDeploymentSpec) GetStage(index int32) (PipelineStage, bool)
func (*KubernetesDeploymentSpec) Validate ¶
func (s *KubernetesDeploymentSpec) Validate() error
Validate returns an error if any wrong configuration value was found.
type KubernetesTrafficRouting ¶ added in v0.3.0
type KubernetesTrafficRouting struct {
Method KubernetesTrafficRoutingMethod `json:"method"`
Istio *IstioTrafficRouting `json:"istio"`
}
type KubernetesTrafficRoutingMethod ¶ added in v0.3.0
type KubernetesTrafficRoutingMethod string
const ( KubernetesTrafficRoutingMethodPodSelector KubernetesTrafficRoutingMethod = "podselector" KubernetesTrafficRoutingMethodIstio KubernetesTrafficRoutingMethod = "istio" KubernetesTrafficRoutingMethodSMI KubernetesTrafficRoutingMethod = "smi" )
func DetermineKubernetesTrafficRoutingMethod ¶ added in v0.3.0
func DetermineKubernetesTrafficRoutingMethod(cfg *KubernetesTrafficRouting) KubernetesTrafficRoutingMethod
DetermineKubernetesTrafficRoutingMethod determines the routing method should be used based on the TrafficRouting config. The default is PodSelector: the way by updating the selector in Service to switching all of traffic.
type LambdaCanaryRolloutStageOptions ¶ added in v0.3.0
type LambdaCanaryRolloutStageOptions struct {
}
LambdaCanaryRolloutStageOptions contains all configurable values for a CLOUDRUN_CANARY_ROLLOUT stage.
type LambdaDeploymentInput ¶ added in v0.3.0
type LambdaDeploymentSpec ¶ added in v0.3.0
type LambdaDeploymentSpec struct {
// Input for Lambda deployment such as where to fetch source code...
Input LambdaDeploymentInput `json:"input"`
// Configuration for quick sync.
QuickSync LambdaSyncStageOptions `json:"quickSync"`
// Pipeline for deploying progressively.
Pipeline *DeploymentPipeline `json:"pipeline"`
}
LambdaDeploymentSpec represents a deployment configuration for Lambda application.
func (*LambdaDeploymentSpec) GetStage ¶ added in v0.3.0
func (s *LambdaDeploymentSpec) GetStage(index int32) (PipelineStage, bool)
func (*LambdaDeploymentSpec) Validate ¶ added in v0.3.0
func (s *LambdaDeploymentSpec) Validate() error
Validate returns an error if any wrong configuration value was found.
type LambdaPromoteStageOptions ¶ added in v0.5.0
type LambdaPromoteStageOptions struct {
Percent int `json:"percent"`
}
LambdaPromoteStageOptions contains all configurable values for a CLOUDRUN_PROMOTE stage.
type LambdaSyncStageOptions ¶ added in v0.3.0
type LambdaSyncStageOptions struct {
}
LambdaSyncStageOptions contains all configurable values for a CLOUDRUN_SYNC stage.
type NotificationReceiver ¶ added in v0.1.7
type NotificationReceiver struct {
Name string `json:"name"`
Slack *NotificationReceiverSlack `json:"slack"`
Webhook *NotificationReceiverWebhook `json:"webhook"`
}
type NotificationReceiverSlack ¶ added in v0.1.7
type NotificationReceiverSlack struct {
HookURL string `json:"hookURL"`
}
type NotificationReceiverWebhook ¶ added in v0.1.7
type NotificationReceiverWebhook struct {
URL string `json:"url"`
}
type NotificationRoute ¶ added in v0.1.7
type NotificationRoute struct {
Name string `json:"name"`
Events []string `json:"events"`
IgnoreEvents []string `json:"ignoreEvents"`
Groups []string `json:"groups"`
IgnoreGroups []string `json:"ignoreGroups"`
Apps []string `json:"apps"`
IgnoreApps []string `json:"ignoreApps"`
Envs []string `json:"envs"`
IgnoreEnvs []string `json:"ignoreEnvs"`
Receiver string `json:"receiver"`
}
type Notifications ¶ added in v0.1.7
type Notifications struct {
Routes []NotificationRoute `json:"routes"`
Receivers []NotificationReceiver `json:"receivers"`
}
type PipedAnalysisProvider ¶
type PipedAnalysisProvider struct {
Name string `json:"name"`
Type model.AnalysisProviderType `json:"type"`
PrometheusConfig *AnalysisProviderPrometheusConfig `json:"prometheus"`
DatadogConfig *AnalysisProviderDatadogConfig `json:"datadog"`
StackdriverConfig *AnalysisProviderStackdriverConfig `json:"stackdriver"`
}
func (*PipedAnalysisProvider) UnmarshalJSON ¶
func (p *PipedAnalysisProvider) UnmarshalJSON(data []byte) error
type PipedCloudProvider ¶
type PipedCloudProvider struct {
Name string
Type model.CloudProviderType
KubernetesConfig *CloudProviderKubernetesConfig
TerraformConfig *CloudProviderTerraformConfig
CloudRunConfig *CloudProviderCloudRunConfig
LambdaConfig *CloudProviderLambdaConfig
}
func (*PipedCloudProvider) UnmarshalJSON ¶
func (p *PipedCloudProvider) UnmarshalJSON(data []byte) error
type PipedGit ¶
type PipedGit struct {
Username string `json:"username"`
Email string `json:"email"`
// Where to write ssh config file.
// Default is "/etc/ssh/ssh_config".
SSHConfigFilePath string `json:"sshConfigFilePath"`
// The host name.
// e.g. github.com, gitlab.com
// Default is "github.com".
Host string `json:"host"`
// The hostname or IP address of the remote git server.
// e.g. github.com, gitlab.com
// Default is the same value with Host.
HostName string `json:"hostName"`
// The path to the private ssh key file.
// This will be used to clone the source code of the git repositories.
SSHKeyFile string `json:"sshKeyFile"`
}
func (PipedGit) ShouldConfigureSSHConfig ¶
type PipedRepository ¶
type PipedRepository struct {
// Unique identifier for this repository.
// This must be unique in the piped scope.
RepoID string `json:"repoId"`
// Remote address of the repository.
// e.g. git@github.com:org/repo1.git
Remote string `json:"remote"`
// The branch should be tracked.
Branch string `json:"branch"`
}
type PipedSpec ¶
type PipedSpec struct {
// The identifier of the project which this piped belongs to.
ProjectID string
// The unique identifier generated for this piped.
PipedID string
// The path to the key generated for this piped.
PipedKeyFile string
WebURL string `json:"webURL"`
// How often to check whether an application should be synced.
// Default is 1m.
SyncInterval Duration `json:"syncInterval"`
// Git configuration needed for git commands.
Git PipedGit `json:"git"`
// List of git repositories this piped will handle.
Repositories []PipedRepository `json:"repositories"`
// List of helm chart repositories that should be added while starting up.
ChartRepositories []HelmChartRepository `json:"chartRepositories"`
CloudProviders []PipedCloudProvider `json:"cloudProviders"`
AnalysisProviders []PipedAnalysisProvider `json:"analysisProviders"`
Notifications Notifications `json:"notifications"`
}
PipedSpec contains configurable data used to while running Piped.
func (*PipedSpec) EnableDefaultKubernetesCloudProvider ¶
func (s *PipedSpec) EnableDefaultKubernetesCloudProvider()
EnableDefaultKubernetesCloudProvider adds the default kubernetes cloud provider if it was not specified.
func (*PipedSpec) FindCloudProvider ¶ added in v0.4.0
func (s *PipedSpec) FindCloudProvider(name string, t model.CloudProviderType) (PipedCloudProvider, bool)
FindCloudProvider finds and returns a Cloud Provider by name and type.
func (*PipedSpec) GetAnalysisProvider ¶
func (s *PipedSpec) GetAnalysisProvider(name string) (PipedAnalysisProvider, bool)
GetAnalysisProvider finds and returns an Analysis Provider config whose name is the given string.
func (*PipedSpec) GetRepository ¶
func (s *PipedSpec) GetRepository(id string) (PipedRepository, bool)
GetRepository finds a repository with the given ID from the configured list.
func (*PipedSpec) GetRepositoryMap ¶
func (s *PipedSpec) GetRepositoryMap() map[string]PipedRepository
GetRepositoryMap returns a map of repositories where key is repo id.
func (*PipedSpec) HasCloudProvider ¶
func (s *PipedSpec) HasCloudProvider(name string, t model.CloudProviderType) bool
HasCloudProvider checks whether the given provider is configured or not.
type PipelineStage ¶
type PipelineStage struct {
Id string
Name model.Stage
Desc string
Timeout Duration
WaitStageOptions *WaitStageOptions
WaitApprovalStageOptions *WaitApprovalStageOptions
AnalysisStageOptions *AnalysisStageOptions
K8sPrimaryRolloutStageOptions *K8sPrimaryRolloutStageOptions
K8sCanaryRolloutStageOptions *K8sCanaryRolloutStageOptions
K8sCanaryCleanStageOptions *K8sCanaryCleanStageOptions
K8sBaselineRolloutStageOptions *K8sBaselineRolloutStageOptions
K8sBaselineCleanStageOptions *K8sBaselineCleanStageOptions
K8sTrafficRoutingStageOptions *K8sTrafficRoutingStageOptions
TerraformSyncStageOptions *TerraformSyncStageOptions
TerraformPlanStageOptions *TerraformPlanStageOptions
TerraformApplyStageOptions *TerraformApplyStageOptions
CloudRunSyncStageOptions *CloudRunSyncStageOptions
CloudRunPromoteStageOptions *CloudRunPromoteStageOptions
LambdaSyncStageOptions *LambdaSyncStageOptions
LambdaCanaryRolloutStageOptions *LambdaCanaryRolloutStageOptions
LambdaPromoteStageOptions *LambdaPromoteStageOptions
}
PiplineStage represents a single stage of a pipeline. This is used as a generic struct for all stage type.
func (*PipelineStage) UnmarshalJSON ¶
func (s *PipelineStage) UnmarshalJSON(data []byte) error
type Pipelineable ¶
type Pipelineable interface {
GetStage(index int32) (PipelineStage, bool)
}
type ProjectStaticUser ¶ added in v0.1.1
type Replicas ¶
func (Replicas) MarshalJSON ¶
func (*Replicas) UnmarshalJSON ¶
type SharedSSOConfig ¶ added in v0.5.0
type SharedSSOConfig struct {
}
func (*SharedSSOConfig) UnmarshalJSON ¶ added in v0.5.0
func (s *SharedSSOConfig) UnmarshalJSON(data []byte) error
type TemplatableAnalysisHTTP ¶
type TemplatableAnalysisHTTP struct {
AnalysisHTTP
Template AnalysisTemplateRef `json:"template"`
}
TemplatableAnalysisHTTP wraps AnalysisHTTP to allow specify template to use.
type TemplatableAnalysisLog ¶
type TemplatableAnalysisLog struct {
AnalysisLog
Template AnalysisTemplateRef `json:"template"`
}
TemplatableAnalysisLog wraps AnalysisLog to allow specify template to use.
type TemplatableAnalysisMetrics ¶
type TemplatableAnalysisMetrics struct {
AnalysisMetrics
Template AnalysisTemplateRef `json:"template"`
}
TemplatableAnalysisMetrics wraps AnalysisMetrics to allow specify template to use.
type TerraformApplyStageOptions ¶
type TerraformApplyStageOptions struct {
// How many times to retry applying terraform changes.
Retries int `json:"retries"`
}
TerraformApplyStageOptions contains all configurable values for a TERRAFORM_APPLY stage.
type TerraformDeploymentInput ¶
type TerraformDeploymentInput struct {
Workspace string `json:"workspace,omitempty"`
TerraformVersion string `json:"terraformVersion,omitempty"`
// List of variables that will be set directly on terraform commands with "-var" flag.
// The variable must be formatted by "key=value" as below:
// "image_id=ami-abc123"
// 'image_id_list=["ami-abc123","ami-def456"]'
// 'image_id_map={"us-east-1":"ami-abc123","us-east-2":"ami-def456"}'
Vars []string `json:"vars,omitempty"`
// List of variable files that will be set on terraform commands with "-var-file" flag.
VarFiles []string `json:"varFiles,omitempty"`
// Automatically reverts all changes from all stages when one of them failed.
// Default is false.
AutoRollback bool `json:"autoRollback"`
Dependencies []string `json:"dependencies,omitempty"`
}
type TerraformDeploymentSpec ¶
type TerraformDeploymentSpec struct {
// Input for Terraform deployment such as terraform version, workspace...
Input TerraformDeploymentInput `json:"input"`
// Configuration for quick sync.
QuickSync TerraformApplyStageOptions `json:"quickSync"`
// Pipeline for deploying progressively.
Pipeline *DeploymentPipeline `json:"pipeline"`
}
TerraformDeploymentSpec represents a deployment configuration for Terraform application.
func (*TerraformDeploymentSpec) GetStage ¶
func (s *TerraformDeploymentSpec) GetStage(index int32) (PipelineStage, bool)
func (*TerraformDeploymentSpec) Validate ¶
func (s *TerraformDeploymentSpec) Validate() error
Validate returns an error if any wrong configuration value was found.
type TerraformPlanStageOptions ¶
type TerraformPlanStageOptions struct {
}
TerraformPlanStageOptions contains all configurable values for a TERRAFORM_PLAN stage.
type TerraformSyncStageOptions ¶ added in v0.3.0
type TerraformSyncStageOptions struct {
// How many times to retry applying terraform changes.
Retries int `json:"retries"`
}
TerraformSyncStageOptions contains all configurable values for a TERRAFORM_SYNC stage.
type WaitApprovalStageOptions ¶
type WaitApprovalStageOptions struct {
Approvers []string `json:"approvers"`
}
WaitStageOptions contains all configurable values for a WAIT_APPROVAL stage.
type WaitStageOptions ¶
type WaitStageOptions struct {
Duration Duration `json:"duration"`
}
WaitStageOptions contains all configurable values for a WAIT stage.